==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QStyleOptionTabV4_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>
#include <QtWidgets/qwidget.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleOptionTabV4(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionTabV4")
    QStyleOptionTabV4 *_ptr = reinterpret_cast<QStyleOptionTabV4 *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleOptionTabV4()
void __qt_construct_QStyleOptionTabV4_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionTabV4()")
    Q_UNUSED(__java_arguments)
    QStyleOptionTabV4 *__qt_this = new(__qtjambi_ptr) QStyleOptionTabV4();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QStyleOptionTabV4
void __qt_destruct_QStyleOptionTabV4(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionTabV4")
    reinterpret_cast<QStyleOptionTabV4*>(ptr)->~QStyleOptionTabV4();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionTabV4::QStyleOptionTabV4()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_initialize_1native__Lio_qt_widgets_QStyleOptionTabV4_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionTabV4::QStyleOptionTabV4()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionTabV4_0, sizeof(QStyleOptionTabV4), typeid(QStyleOptionTabV4), false, &deleter_QStyleOptionTabV4, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_setTabIndex_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint tabIndex0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionTabV4 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionTabV4>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->tabIndex = static_cast<int>(tabIndex0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_tabIndex_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionTabV4 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionTabV4>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->tabIndex;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionTabV4 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionTabV4>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionTabV4(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionTabV4>("QStyleOptionTabV4", "io/qt/widgets/QStyleOptionTabV4");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionTabV4, {
        ConstructorInfo(&__qt_construct_QStyleOptionTabV4_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionTabV4);
    registerMetaType<QStyleOptionTabV4>("QStyleOptionTabV4");
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOptionTab), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOptionTab *object = reinterpret_cast<QStyleOptionTab *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = false;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = false;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QStyleOptionTabV4_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>
#include <QtWidgets/qwidget.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleOptionTabV4(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionTabV4")
    QStyleOptionTabV4 *_ptr = reinterpret_cast<QStyleOptionTabV4 *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleOptionTabV4()
void __qt_construct_QStyleOptionTabV4(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionTabV4()")
    Q_UNUSED(__java_arguments)
    QStyleOptionTabV4 *__qt_this = new(__qtjambi_ptr) QStyleOptionTabV4();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QStyleOptionTabV4::QStyleOptionTabV4()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_initialize_1native__Lio_qt_widgets_QStyleOptionTabV4_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionTabV4::QStyleOptionTabV4()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionTabV4, sizeof(QStyleOptionTabV4), typeid(QStyleOptionTabV4), false, &deleter_QStyleOptionTabV4, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleOptionTabV4(QStyleOptionTabV4)
void __qt_construct_QStyleOptionTabV4_cref_QStyleOptionTabV4(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionTabV4(QStyleOptionTabV4)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionTabV4& __qt_other0 = qtjambi_cast<const QStyleOptionTabV4& >(__jni_env, other0);
    QStyleOptionTabV4 *__qt_this = new(__qtjambi_ptr) QStyleOptionTabV4(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QStyleOptionTabV4::QStyleOptionTabV4(QStyleOptionTabV4)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_initialize_1native__Lio_qt_widgets_QStyleOptionTabV4_2Lio_qt_widgets_QStyleOptionTabV4_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionTabV4::QStyleOptionTabV4(QStyleOptionTabV4)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionTabV4_cref_QStyleOptionTabV4, sizeof(QStyleOptionTabV4), typeid(QStyleOptionTabV4), false, &deleter_QStyleOptionTabV4, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleOptionTabV4
void __qt_destruct_QStyleOptionTabV4(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionTabV4")
    reinterpret_cast<QStyleOptionTabV4*>(ptr)->~QStyleOptionTabV4();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_setTabIndex_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint tabIndex0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionTabV4 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionTabV4>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->tabIndex = static_cast<int>(tabIndex0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_tabIndex_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionTabV4 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionTabV4>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->tabIndex;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionTabV4_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionTabV4 *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionTabV4>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionTabV4(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionTabV4>("QStyleOptionTabV4", "io/qt/widgets/QStyleOptionTabV4");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionTabV4, {
        ConstructorInfo(&__qt_construct_QStyleOptionTabV4, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionTabV4_cref_QStyleOptionTabV4, "Lio/qt/widgets/QStyleOptionTabV4;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionTabV4);
    registerMetaType<QStyleOptionTabV4>("QStyleOptionTabV4");
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOptionTab), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOptionTab *object = reinterpret_cast<QStyleOptionTab *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = false;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = false;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
